DataSource

Struct DataSource 

pub struct DataSource {
Show 18 fields pub authorization_type: Option<String>, pub client_id: Option<String>, pub data_refresh_type: Option<String>, pub data_source_id: Option<String>, pub default_data_refresh_window_days: Option<i32>, pub default_schedule: Option<String>, pub description: Option<String>, pub display_name: Option<String>, pub help_url: Option<String>, pub manual_runs_disabled: Option<bool>, pub minimum_schedule_interval: Option<Duration>, pub name: Option<String>, pub parameters: Option<Vec<DataSourceParameter>>, pub scopes: Option<Vec<String>>, pub supports_custom_schedule: Option<bool>, pub supports_multiple_transfers: Option<bool>, pub transfer_type: Option<String>, pub update_deadline_seconds: Option<i32>,
}
Defines the properties and custom parameters for a data source.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

authorization_type: Option<String>

Indicates the type of authorization.

client_id: Option<String>

Data source client id which should be used to receive refresh token.

data_refresh_type: Option<String>

Specifies whether the data source supports automatic data refresh for the past few days, and how it’s supported. For some data sources, data might not be complete until a few days later, so it’s useful to refresh data automatically.

data_source_id: Option<String>

Data source id.

default_data_refresh_window_days: Option<i32>

Default data refresh window on days. Only meaningful when data_refresh_type = SLIDING_WINDOW.

default_schedule: Option<String>

Default data transfer schedule. Examples of valid schedules include: 1st,3rd monday of month 15:30, every wed,fri of jan,jun 13:15, and first sunday of quarter 00:00.

description: Option<String>

User friendly data source description string.

display_name: Option<String>

User friendly data source name.

help_url: Option<String>

Url for the help document for this data source.

manual_runs_disabled: Option<bool>

Disables backfilling and manual run scheduling for the data source.

minimum_schedule_interval: Option<Duration>

The minimum interval for scheduler to schedule runs.

name: Option<String>

Output only. Data source resource name.

parameters: Option<Vec<DataSourceParameter>>

Data source parameters.

scopes: Option<Vec<String>>

Api auth scopes for which refresh token needs to be obtained. These are scopes needed by a data source to prepare data and ingest them into BigQuery, e.g., https://www.googleapis.com/auth/bigquery

supports_custom_schedule: Option<bool>

Specifies whether the data source supports a user defined schedule, or operates on the default schedule. When set to true, user can override default schedule.

supports_multiple_transfers: Option<bool>

Deprecated. This field has no effect.

transfer_type: Option<String>

Deprecated. This field has no effect.

update_deadline_seconds: Option<i32>

The number of seconds to wait for an update from the data source before the Data Transfer Service marks the transfer as FAILED.