DataSourceParameter

Struct DataSourceParameter 

pub struct DataSourceParameter {
Show 17 fields pub allowed_values: Option<Vec<String>>, pub deprecated: Option<bool>, pub description: Option<String>, pub display_name: Option<String>, pub fields: Option<Vec<DataSourceParameter>>, pub immutable: Option<bool>, pub max_list_size: Option<i64>, pub max_value: Option<f64>, pub min_value: Option<f64>, pub param_id: Option<String>, pub recurse: Option<bool>, pub repeated: Option<bool>, pub required: Option<bool>, pub type_: Option<String>, pub validation_description: Option<String>, pub validation_help_url: Option<String>, pub validation_regex: Option<String>,
}
A parameter used to define custom fields in a data source definition.

This type is not used in any activity, and only used as part of another schema.

Fields

allowed_values: Option<Vec<String>>

All possible values for the parameter.

deprecated: Option<bool>

If true, it should not be used in new transfers, and it should not be visible to users.

description: Option<String>

Parameter description.

display_name: Option<String>

Parameter display name in the user interface.

fields: Option<Vec<DataSourceParameter>>

Deprecated. This field has no effect.

immutable: Option<bool>

Cannot be changed after initial creation.

max_list_size: Option<i64>

For list parameters, the max size of the list.

max_value: Option<f64>

For integer and double values specifies maximum allowed value.

min_value: Option<f64>

For integer and double values specifies minimum allowed value.

param_id: Option<String>

Parameter identifier.

recurse: Option<bool>

Deprecated. This field has no effect.

repeated: Option<bool>

Deprecated. This field has no effect.

required: Option<bool>

Is parameter required.

type_: Option<String>

Parameter type.

validation_description: Option<String>

Description of the requirements for this field, in case the user input does not fulfill the regex pattern or min/max values.

validation_help_url: Option<String>

URL to a help document to further explain the naming requirements.

validation_regex: Option<String>

Regular expression which can be used for parameter validation.