pub struct EventDrivenSchedule {
pub pubsub_subscription: Option<String>,
}Expand description
Options customizing EventDriven transfers schedule.
This type is not used in any activity, and only used as part of another schema.
Fields
pubsub_subscription: Option<String>Pub/Sub subscription name used to receive events. Only Google Cloud Storage data source support this option. Format: projects/{project}/subscriptions/{subscription}