pub struct ListTransferLogsResponse {
pub next_page_token: Option<String>,
pub transfer_messages: Option<Vec<TransferMessage>>,
}Expand description
The returned list transfer run messages.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>Output only. The next-pagination token. For multiple-page list results, this token can be used as the GetTransferRunLogRequest.page_token to request the next page of list results.
transfer_messages: Option<Vec<TransferMessage>>Output only. The stored pipeline transfer messages.