pub struct ListTransferRunsResponse {
pub next_page_token: Option<String>,
pub transfer_runs: Option<Vec<TransferRun>>,
}Expand description
The returned list of pipelines in the project.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations transfer configs runs list projects (response)
- transfer configs runs list projects (response)
Fields
next_page_token: Option<String>Output only. The next-pagination token. For multiple-page list results, this token can be used as the ListTransferRunsRequest.page_token to request the next page of list results.
transfer_runs: Option<Vec<TransferRun>>Output only. The stored pipeline transfer runs.