pub struct ScheduleOptionsV2 {
pub event_driven_schedule: Option<EventDrivenSchedule>,
pub manual_schedule: Option<ManualSchedule>,
pub time_based_schedule: Option<TimeBasedSchedule>,
}Expand description
V2 options customizing different types of data transfer schedule. This field supports existing time-based and manual transfer schedule. Also supports Event-Driven transfer schedule. ScheduleOptionsV2 cannot be used together with ScheduleOptions/Schedule.
This type is not used in any activity, and only used as part of another schema.
Fields
event_driven_schedule: Option<EventDrivenSchedule>Event driven transfer schedule options. If set, the transfer will be scheduled upon events arrial.
manual_schedule: Option<ManualSchedule>Manual transfer schedule. If set, the transfer run will not be auto-scheduled by the system, unless the client invokes StartManualTransferRuns. This is equivalent to disable_auto_scheduling = true.
time_based_schedule: Option<TimeBasedSchedule>Time based transfer schedule options. This is the default schedule option.