pub struct TransferConfig {Show 21 fields
pub data_refresh_window_days: Option<i32>,
pub data_source_id: Option<String>,
pub dataset_region: Option<String>,
pub destination_dataset_id: Option<String>,
pub disabled: Option<bool>,
pub display_name: Option<String>,
pub email_preferences: Option<EmailPreferences>,
pub encryption_configuration: Option<EncryptionConfiguration>,
pub error: Option<Status>,
pub managed_table_type: Option<String>,
pub name: Option<String>,
pub next_run_time: Option<DateTime<Utc>>,
pub notification_pubsub_topic: Option<String>,
pub owner_info: Option<UserInfo>,
pub params: Option<HashMap<String, Value>>,
pub schedule: Option<String>,
pub schedule_options: Option<ScheduleOptions>,
pub schedule_options_v2: Option<ScheduleOptionsV2>,
pub state: Option<String>,
pub update_time: Option<DateTime<Utc>>,
pub user_id: Option<i64>,
}Expand description
Represents a data transfer configuration. A transfer configuration contains all metadata needed to perform a data transfer. For example, destination_dataset_id specifies where data should be stored. When a new transfer configuration is created, the specified destination_dataset_id is created when needed and shared with the appropriate data source service account.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations transfer configs create projects (request|response)
- locations transfer configs get projects (response)
- locations transfer configs patch projects (request|response)
- transfer configs create projects (request|response)
- transfer configs get projects (response)
- transfer configs patch projects (request|response)
Fields
data_refresh_window_days: Option<i32>The number of days to look back to automatically refresh the data. For example, if data_refresh_window_days = 10, then every day BigQuery reingests data for [today-10, today-1], rather than ingesting data for just [today-1]. Only valid if the data source supports the feature. Set the value to 0 to use the default value.
data_source_id: Option<String>Data source ID. This cannot be changed once data transfer is created. The full list of available data source IDs can be returned through an API call: https://cloud.google.com/bigquery-transfer/docs/reference/datatransfer/rest/v1/projects.locations.dataSources/list
dataset_region: Option<String>Output only. Region in which BigQuery dataset is located.
destination_dataset_id: Option<String>The BigQuery target dataset id.
disabled: Option<bool>Is this config disabled. When set to true, no runs will be scheduled for this transfer config.
display_name: Option<String>User specified display name for the data transfer.
email_preferences: Option<EmailPreferences>Email notifications will be sent according to these preferences to the email address of the user who owns this transfer config.
encryption_configuration: Option<EncryptionConfiguration>The encryption configuration part. Currently, it is only used for the optional KMS key name. The BigQuery service account of your project must be granted permissions to use the key. Read methods will return the key name applied in effect. Write methods will apply the key if it is present, or otherwise try to apply project default keys if it is absent.
error: Option<Status>Output only. Error code with detailed information about reason of the latest config failure.
managed_table_type: Option<String>The classification of the destination table.
name: Option<String>Identifier. The resource name of the transfer config. Transfer config names have the form either projects/{project_id}/locations/{region}/transferConfigs/{config_id} or projects/{project_id}/transferConfigs/{config_id}, where config_id is usually a UUID, even though it is not guaranteed or required. The name is ignored when creating a transfer config.
next_run_time: Option<DateTime<Utc>>Output only. Next time when data transfer will run.
notification_pubsub_topic: Option<String>Pub/Sub topic where notifications will be sent after transfer runs associated with this transfer config finish. The format for specifying a pubsub topic is: projects/{project_id}/topics/{topic_id}
owner_info: Option<UserInfo>Output only. Information about the user whose credentials are used to transfer data. Populated only for transferConfigs.get requests. In case the user information is not available, this field will not be populated.
params: Option<HashMap<String, Value>>Parameters specific to each data source. For more information see the bq tab in the ‘Setting up a data transfer’ section for each data source. For example the parameters for Cloud Storage transfers are listed here: https://cloud.google.com/bigquery-transfer/docs/cloud-storage-transfer#bq
schedule: Option<String>Data transfer schedule. If the data source does not support a custom schedule, this should be empty. If it is empty, the default value for the data source will be used. The specified times are in UTC. Examples of valid format: 1st,3rd monday of month 15:30, every wed,fri of jan,jun 13:15, and first sunday of quarter 00:00. See more explanation about the format here: https://cloud.google.com/appengine/docs/flexible/python/scheduling-jobs-with-cron-yaml#the_schedule_format NOTE: The minimum interval time between recurring transfers depends on the data source; refer to the documentation for your data source.
schedule_options: Option<ScheduleOptions>Options customizing the data transfer schedule.
schedule_options_v2: Option<ScheduleOptionsV2>Options customizing different types of data transfer schedule. This field replaces “schedule” and “schedule_options” fields. ScheduleOptionsV2 cannot be used together with ScheduleOptions/Schedule.
state: Option<String>Output only. State of the most recently updated transfer run.
update_time: Option<DateTime<Utc>>Output only. Data transfer modification time. Ignored by server on input.
user_id: Option<i64>Deprecated. Unique ID of the user on whose behalf transfer is done.